@@ -117,6 +117,19 @@ sub out
 }
 
 
+=head2 $t->minsize()
+
+Returns the minimum size this table can be. If it is smaller than this, then the table
+must be bad and should be deleted or whatever.
+
+=cut
+
+sub minsize
+{
+    return 54;
+}
+
+
 =head2 $t->XML_element($context, $depth, $key, $value)
 
 Handles date process for the XML exporter
@@ -196,16 +209,16 @@ storable time.
 sub getdate
 {
     my ($self, $is_create) = @_;
-    my ($arr) = $self->{$is_create ? 'created' : 'modified'};
+    my (@arr) = (@{$self->{$is_create ? 'created' : 'modified'}});
 
-    $arr->[1] -= 2082844800;        # seconds between 1/Jan/1904 and 1/Jan/1970 (midnight)
-    if ($arr->[1] < 0)
+    $arr[1] -= 2082844800;        # seconds between 1/Jan/1904 and 1/Jan/1970 (midnight)
+    if ($arr[1] < 0)
     {
-        $arr->[1] += 0xFFFFFFF; $arr->[1]++;
-        $arr->[0]--;
+        $arr[1] += 0xFFFFFFF; $arr[1]++;
+        $arr[0]--;
     }
-    return undef if $arr->[0] != 0;
-    return $arr->[1];
+    return undef if $arr[0] != 0;
+    return $arr[1];
 }
 
 
@@ -243,8 +256,18 @@ None known
 
 =head1 AUTHOR
 
-Martin Hosken Martin_Hosken@sil.org. See L<Font::TTF::Font> for copyright and
-licensing.
+Martin Hosken L<http://scripts.sil.org/FontUtils>. 
+
+
+=head1 LICENSING
+
+Copyright (c) 1998-2016, SIL International (http://www.sil.org) 
+
+This module is released under the terms of the Artistic License 2.0. 
+For details, see the full text of the license in the file LICENSE.
+
+
 
 =cut
 
+
